@@ -28,7 +28,7 @@ use Cwd;
 
 #--------------> START PROGRAM <--------------#
 
-$VERSION = '1.21';
+$VERSION = '1.31';
 
 BEGIN {
    my @errors;
@@ -282,28 +282,30 @@ sub create_image { # create a security image with random options and styles
    my $code  = shift;
    my $START = shift;
    my $s     = $self->{rnd_sty};
-   my $i     = GD::SecurityImage
-   ->new(lines   => $s->{lines},
-         bgcolor => $s->{bgcolor},
-         %{ $self->{rnd_opt} })
+   my $i     = GD::SecurityImage->new(
+      lines   => $s->{lines},
+      bgcolor => $s->{bgcolor},
+      %{ $self->{rnd_opt} },
+   )
    ->random  ($code)
    ->create  (ttf => $s->{name}, $s->{text_color}, $s->{line_color})
    ->particle($s->{dots} ? ($s->{particle}, $s->{dots}) 
                          : ($s->{particle})
    );
    if ($i->gdbox_empty) {
-      die qq~An error occurred while opening the font file '$config{font}'. Please set font option to an "exact" path not relative. Error: $@~;
+      die qq~An error occurred while opening the font file '$config{font}'. Please set font option to an "exact" path, not relative. Error: $@~;
    }
    if ($config{img_stat}) {
-      $i->set_tl(x      => 'right',
-                 y      => 'up',
-                 gd     => 1,
-                 strip  => 1,
-                 color  => "#000000",
-                 scolor => "#FFFFFF",
-                 ptsize => $i->{IS_MAGICK} ? 12 : 8, # low-level access to an object table is not a good thing, since the author can change/delete it without notification in later releases ;)
-                 text   => sprintf "Security Image generated at %.3f seconds", Time::HiRes::time() - $START,
-      )->insert_text('ttf');
+      $i->info_text(
+         x      => 'right',
+         y      => 'up',
+         gd     => 1,
+         strip  => 1,
+         color  => "#000000",
+         scolor => "#FFFFFF",
+         ptsize => $i->{IS_MAGICK} ? 12 : 8, # low-level access to an object table is not a good thing, since the author can change/delete it without notification in later releases ;)
+         text   => sprintf "Security Image generated at %.3f seconds", Time::HiRes::time() - $START,
+      );
    }
    my @image = $i->out(force => $config{itype});
    return @image;
@@ -314,8 +316,8 @@ sub create_image { # create a security image with random options and styles
 sub all_options {
    my %gd = (
    gd_ttf => {
-      width      => 210,
-      height     => 60,
+      width      => 220,
+      height     => 90,
       send_ctobg => 1,
       font       => $config{font},
       ptsize     => 30,
@@ -341,7 +343,7 @@ sub all_options {
    my %magick = (
    magick => {
       width      => 250,
-      height     => 80,
+      height     => 100,
       send_ctobg => 1,
       font       => $config{font},
       ptsize     => 50,
@@ -515,7 +517,8 @@ Copyright 2004-2005 Burak Grsoy. All rights reserved.
 
 =head1 LICENSE
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself. 
+This program is free software; you can redistribute it and/or modify 
+it under the same terms as Perl itself, either Perl version 5.8.6 or, 
+at your option, any later version of Perl 5 you may have available.
 
 =cut
